@@ -84,11 +84,26 @@ validate /etc/ssh/sshd_config
           'yes'
         ]
       },
+      'AuthorizedKeysFile2',
+      {
+        'cargo' => {
+          'value_type' => 'uniline',
+          'type' => 'leaf'
+        },
+        'status' => 'deprecated',
+        'experience' => 'advanced',
+        'type' => 'list',
+        'description' => 'Specifies the file that contains the public keys that can be used for user authentication. AuthorizedKeysFile may contain tokens of the form %T which are substituted during connection setup.'
+      },
       'AuthorizedKeysFile',
       {
-        'value_type' => 'uniline',
+        'migrate_values_from' => '- AuthorizedKeysFile2',
+        'cargo' => {
+          'value_type' => 'uniline',
+          'type' => 'leaf'
+        },
         'experience' => 'advanced',
-        'type' => 'leaf',
+        'type' => 'list',
         'description' => 'Specifies the file that contains the public keys that can be used for user authentication. AuthorizedKeysFile may contain tokens of the form %T which are substituted during connection setup.'
       },
       'Banner',
